@@ -13,7 +13,7 @@ K8S_VERSION = 1
 logger = logging.getLogger(__name__)
 
 
-def build(dag, resource):
+def build(dag, resource, meta={}):
     """build a docker image
 
     Parameters
@@ -22,6 +22,8 @@ def build(dag, resource):
         the dag that this image will be built for
     resource : executor_s3.S3Resource
         a tarball stored on s3 with a Dockerfile at its root.
+    meta : dict
+        metadata to pass through
 
     Returns
     -------
@@ -29,10 +31,10 @@ def build(dag, resource):
         the docker image
     """
     fn = dag.load(DAG_NAME, DAG_VERSION)
-    return fn(resource)
+    return fn(resource, meta=meta)
 
 
-def run(dag, image, *args):
+def run(dag, image, *args, meta={}):
     """run a docker image on kubernetes
 
     Parameters
@@ -41,6 +43,8 @@ def run(dag, image, *args):
         the dag that this image will be built for
     image : DockerResource
         the docker image you want to run
+    meta : dict
+        metadata to pass through
 
     Returns
     -------
@@ -49,4 +53,4 @@ def run(dag, image, *args):
     """
     k8s = dag.load(K8S_DAG, K8S_VERSION)
     f = dag.from_py([k8s, image])
-    return f(*args)
+    return f(*args, meta=meta)
